import multer from "multer";
import { FileSystemHelper } from "../helpers/fileSystemHelper";
import path from "path";
import BadRequestException from "../exceptions/badRequestException";

export const clubImageStorage = multer.diskStorage({
  destination: FileSystemHelper.formatPath("/app"),
  filename: function (req, file, cb) {
    const fileExtension = path.extname(file.originalname).toLowerCase();

    if (file.fieldname === "icon") {
      cb(null, "admin-icon" + fileExtension);
    } else if (file.fieldname === "logo") {
      cb(null, "admin-logo" + fileExtension);
    } else {
      cb(null, file.originalname);
    }
  },
});

export const clubImageMulter = multer({
  storage: clubImageStorage,
  fileFilter(req, file, cb) {
    if (file.mimetype.startsWith("image/png")) {
      cb(null, true);
    } else {
      cb(new BadRequestException("Wrong file format"));
    }
  },
});

export const clubImageUpload = clubImageMulter.fields([
  { name: "icon", maxCount: 1 },
  { name: "logo", maxCount: 1 },
]);
